@@ -9,6 +9,7 @@
 //' @param vLogparams a vector containing the log of the parameters p, q, gamma
 //' @param vX frequency vector of length n counting the numbers of purchases
 //' @param vM_x the observed average spending for every customer during the calibration time.
+//' @template template_param_rcppvn
 //'
 //' @details
 //' \code{vLogparams} is a vector with the parameters for the Gamma-Gamma model.
@@ -25,7 +26,8 @@
 // [[Rcpp::export]]
 double gg_LL(const arma::vec& vLogparams,
              const arma::vec& vX,
-             const arma::vec& vM_x)
+             const arma::vec& vM_x,
+             const arma::vec& vN)
 {
 
   const double p = std::exp(vLogparams(0));
@@ -33,16 +35,16 @@ double gg_LL(const arma::vec& vLogparams,
   const double gamma = std::exp(vLogparams(2));
 
   // Calculate the likelood for all != 0 values
-  arma::uvec vNonZero = find((vX != 0.0) && (vM_x != 0.0));
+  const arma::uvec vNonZero = find((vX != 0.0) && (vM_x != 0.0));
 
   // arma::vec vLL(vX.n_elem);
-  arma::vec vLL = q * std::log(gamma)
+  const arma::vec vLL = q * std::log(gamma)
     + ((p * vX(vNonZero) - 1) % arma::log(vM_x(vNonZero)))
     + ((p * vX(vNonZero)) % arma::log(vX(vNonZero)))
     - (p * vX(vNonZero) + q) % arma::log(gamma + vM_x(vNonZero) % vX(vNonZero))
     - clv::vec_lbeta(p * vX(vNonZero), q);
 
-  return -1 * arma::sum(vLL);
+  return -1 * arma::sum(vLL % vN(vNonZero));
 }
 
 
