@@ -1,6 +1,5 @@
+skip_on_cran()
 
-# Load required data ---------------------------------------------------------------------------------
-data("apparelTrans")
 data("cdnow")
 
 # Parameter data.transactions ------------------------------------------------------------------------------------
