@@ -9,16 +9,17 @@ skip_on_cran()
 
 fitted.dyncov <- fct.helper.dyncov.quickfit.apparel.data(
   hessian=TRUE,
-  names.cov.life = c("Marketing", "Gender"),
-  names.cov.trans = c("Marketing", "Gender", "Channel")
+  names.cov.life = c("High.Season", "Gender"),
+  names.cov.trans = c("High.Season", "Gender", "Channel")
 )
 
+
 fct.helper.runability.dyncov.all.downstream(
   fitted.dyncov=fitted.dyncov,
   names.params=
     c("r", "alpha", "s", "beta",
-      "life.Marketing",  "life.Gender",
-      "trans.Marketing", "trans.Gender",  "trans.Channel")
+      "life.High.Season",  "life.Gender",
+      "trans.High.Season", "trans.Gender",  "trans.Channel")
 )
 
 fct.testthat.runability.dynamiccov.LL.is.correct(
@@ -32,8 +33,8 @@ test_that("Dyncov works with additional model specifications", {
   clv.apparel.dyn <- fct.helper.create.clvdata.apparel.dyncov()
 
   fn.fit.dyncov.spec <- function(...){
-    covs.life <- c("Marketing", "Gender")
-    covs.trans <- c("Marketing", "Gender", "Channel")
+    covs.life <- c("High.Season", "Gender")
+    covs.trans <- c("High.Season", "Gender", "Channel")
 
     expect_silent(fitted.dyncov <- fit.apparel.dyncov(
       names.cov.life = covs.life,
@@ -78,10 +79,10 @@ test_that("Dyncov works with additional model specifications", {
   }
 
   # regularization -------------------------------------------------------------
-  fn.fit.dyncov.spec(reg.lambdas = c(trans=10, life=20))
+  fn.fit.dyncov.spec(reg.lambdas = c(trans=10, life=10))
 
   # constrained covs -----------------------------------------------------------
-  fn.fit.dyncov.spec(names.cov.constr = "Gender")
+  fn.fit.dyncov.spec(names.cov.constr = "High.Season")
 
   # correlation ----------------------------------------------------------------
   fn.fit.dyncov.spec(use.cor=TRUE)
@@ -90,5 +91,5 @@ test_that("Dyncov works with additional model specifications", {
   fn.fit.dyncov.spec(
     use.cor=TRUE,
     names.cov.constr = "Gender",
-    reg.lambda = c(trans=10, life=20))
+    reg.lambda = c(trans=10, life=10))
 })
